import http from '@/api'
import type { BaseEntity, ResponseEntity } from '@/typings/api'

export interface FlowGroup extends BaseEntity {
  name: string
  sort: number
}

export interface FlowGroupResponse extends FlowGroup, ResponseEntity {}

export interface FlowGroupQuery {
  name?: string
}

export const getList = async (query?: FlowGroupQuery) => {
  const res = await http.get<FlowGroup[]>('/group', query)
  if (res.success) {
    const options = res.data
    options.push({
      id: '0',
      name: '其他',
      sort: 999
    })
    return options
  }
}

export const create = (flowGroup: FlowGroup) => {
  return http.post<FlowGroup>('/group', flowGroup)
}

export const update = (flowGroup: FlowGroup) => {
  return http.put<FlowGroup>('/group', flowGroup)
}

export const createOrUpdate = (flowGroup: FlowGroup) => {
  return flowGroup.id ? update(flowGroup) : create(flowGroup)
}

export const deleteByIds = (ids: string[]) => {
  return http.delete('/group', ids)
}

export const sort = (newId: string, oldId: string) => {
  return http.put(`/group/sort/${newId}/${oldId}`)
}
