import http from '@/api'
import type { BaseEntity, PageQuery, ResultPage } from '@/typings/api'
import type { FormInfo } from '@/api/modules/flow/define'

export interface FlowInstance extends BaseEntity {
  name: string
  definitionId: string
  version: number
  startUserId: string
  startTime: string
  endTime: string
  duration: number
  cancelDays: number
  status: ProcessStatus
}

export enum ProcessStatus {
  RUNNING = 0,
  COMPLETED = 1,
  CANCELED = 2,
  REFUSE = 3,
  REJECT = 4
}

export const ProcessStatusDescriptions: { [key in ProcessStatus | -1]: string } = {
  [ProcessStatus.RUNNING]: '进行中',
  [ProcessStatus.COMPLETED]: '通过',
  [ProcessStatus.CANCELED]: '撤回',
  [ProcessStatus.REFUSE]: '拒绝',
  [ProcessStatus.REJECT]: '回退',
  '-1': ''
}

export interface FlowInstanceQuery extends PageQuery {
  id: string
  name: string
  startUserId?: string
  modelCode: string
  definitionId: string
  status?: number
  startDates?: string[]
  endDates?: string[]
}

export const list = (query: FlowInstanceQuery) => {
  return http.get<ResultPage<FlowInstance>>('/instance', query)
}

export const me = (query: FlowInstanceQuery) => {
  return http.get<ResultPage<FlowInstance>>('/instance/me', query)
}

export const copy = (query: FlowInstanceQuery) => {
  return http.get<ResultPage<FlowInstance>>('/instance/copy', query)
}

export const getInstance = (instanceId: string) => {
  return http.get<FlowInstance>(`/instance/${instanceId}`)
}

export const getVariables = (instanceId: string) => {
  return http.get<Recordable>(`/instance/variables/${instanceId}`)
}

export const getForm = (instanceId: string) => {
  return http.get<FormInfo>(`/instance/form/${instanceId}`)
}

export const cancel = (instanceIds: string[]) => {
  return http.put('/instance/cancel', instanceIds)
}

export const getPrintData = (instanceId: string) => {
  return http.get<string>(`/instance/print/${instanceId}`)
}
