import type { BaseEntity, ResponseEntity } from '@/typings/api'
import type { FormConf } from '@/components/FormParser/type'
import http from '@/api'
import { type FlowGroup, getList as getGroups } from './group'
import type { FlowNode } from './flowDesign'

export interface FlowModel extends BaseEntity {
  code: string
  name: string
  sort: number
  icon: ModelIcon
  process: FlowNode
  form: FormConf
  version: number
  groupId: string
  remark: string
  admin: string[]
  enable: boolean
  settings: ModelSettings
}

export interface ModelSettings {
  cancel: {
    enable: boolean
    days: number
  }
  title: {
    type: 'default' | 'custom'
    value?: string
  }
  print: {
    enable: boolean
    template: string
  }
}

export interface ModelIcon {
  name: string
  color: string
  bgColor: string
}

export interface FlowModelQuery {
  name?: string
}

export interface FlowModelResult extends FlowModel, ResponseEntity {}

export interface ModelGroup extends FlowGroup {
  models: FlowModelResult[]
}

export const getGroupList = async () => {
  const all = await Promise.all([getGroups(), getList()])
  if (all[0]) {
    const groups = all[0]
    const models = all[1].success ? all[1].data : []
    return groups.map((group) => {
      return {
        ...group,
        models: models.filter((model) => model.groupId === group.id)
      }
    })
  }
}

export const getList = (query?: FlowModelQuery) => {
  return http.get<FlowModelResult[]>('/model', query)
}

export const getModel = (modelId: string) => {
  return http.get<FlowModelResult>(`/model/${modelId}`)
}

export const create = (flowModel: FlowModel) => {
  return http.post<FlowModelResult>('/model', flowModel)
}

export const update = (flowModel: FlowModel) => {
  return http.put<FlowModelResult>('/model', flowModel)
}

export const suspend = (modelId: string) => {
  return http.put<FlowModelResult>(`/model/suspend/${modelId}`)
}
export const createOrUpdate = (flowModel: FlowModel) => {
  return flowModel.id ? update(flowModel) : create(flowModel)
}

export const deploy = (modelId: string) => {
  return http.post<FlowModelResult>(`/model/deploy/${modelId}`)
}

export const deleteByIds = (ids: string[]) => {
  return http.delete('/model', ids)
}
