import http from '@/api'
import type { FormInfo } from '@/api/modules/flow/define'
import type { BaseEntity, PageQuery, ResultPage } from '@/typings/api'
import { ProcessStatus } from '@/api/modules/flow/instance'
import type { FlowNode } from '@/api/modules/flow/flowDesign'

export interface FlowTask extends BaseEntity {
  id: string
  name: string
  instanceId: string
  instanceName: string
  definitionId: string
  assignee: string
  startUserId: string
  startTime: string
  endTime: string
  dueDate: string
  duration: number
  status: ProcessStatus
}

/**
 * 评论
 */
export interface FlowComment {
  // 流程实例id
  instanceId?: string
  // 任务id
  taskId: string
  // 评论内容
  content: string
  // 评论人
  userId: string
  // 评论时间
  time?: string
  // 附件
  attachments: Attachment[]
}

/**
 * 附件
 */
export interface Attachment {
  // 文件类型
  type: string
  // 文件名称
  name: string
  // 文件大小
  size: number
  // 文件地址
  url: string
}

export interface TaskForm {
  taskId: string
  values: Recordable
  comment: FlowComment
}

export interface RejectTaskForm extends TaskForm {
  targetNode: string
}

export interface TransferTaskForm extends TaskForm {
  assignee: string
}

export interface TaskQuery extends PageQuery {
  name: string
  startUserId: string
  instanceName: string
  instanceId: string
  modelCode: string
  definitionId: string
  status?: number
  startDates?: string[]
  endDates?: string[]
}

export const todo = (query: TaskQuery) => {
  return http.get<ResultPage<FlowTask>>('/task/todo', query)
}

export const done = (query: TaskQuery) => {
  return http.get<ResultPage<FlowTask>>('/task/done', query)
}

export const getForm = (taskId: string) => {
  return http.get<FormInfo>(`/task/form/${taskId}`)
}

export const complete = (taskForm: TaskForm) => {
  return http.post('/task/complete', taskForm)
}

export const rejectTask = (taskForm: RejectTaskForm) => {
  return http.post('/task/reject', taskForm)
}

export const transfer = (taskForm: TransferTaskForm) => {
  return http.post('/task/transfer', taskForm)
}

export const addSign = (taskForm: TransferTaskForm) => {
  return http.post('/task/addSign', taskForm)
}

export const removeSign = (taskForm: TransferTaskForm) => {
  return http.post('/task/removeSign', taskForm)
}

export const refuseTask = (taskForm: TaskForm) => {
  return http.post('/task/refuse', taskForm)
}

export const delegate = (taskForm: TransferTaskForm) => {
  return http.post('/task/delegate', taskForm)
}

export const comment = (taskForm: TaskForm) => {
  return http.post('/task/comment', taskForm)
}

export const getComments = (taskId: string) => {
  return http.get<FlowComment[]>(`/task/comment/${taskId}`)
}

export const getParentNodes = (taskId: string) => {
  return http.get<FlowNode[]>(`/task/parentNodes/${taskId}`)
}

export const getMultiInstanceUnStartedUsers = (taskId: string) => {
  return http.get<string[]>(`/task/unStartedUsers/${taskId}`)
}
export const getMultiInstanceTaskUnUsers = (taskId: string) => {
  return http.get<string[]>(`/task/unUsers/${taskId}`)
}
