import http from '@/api'
import type { BaseEntity, PageQuery, ResultPage } from '@/typings/api'

export interface User extends BaseEntity {
  name: string
  username: string
  avatar: string
  sex: number
  phone: string
  email: string
  enabled: boolean
  deptId: string
  leader: string
  roleIds: string[]
}

export interface UserQuery extends PageQuery {
  name?: string
  username?: string
  sex?: number
  phone?: string
  email?: string
  enabled?: boolean
  deptId?: string
}

export const list = (name?: String) => {
  return http.get<User[]>('/user/list', { name })
}
export const search = (params: Recordable) => {
  return http.get<User[]>('/user/search', params)
}
export const getList = (params: UserQuery) => {
  return http.get<ResultPage<User>>('/user', params)
}
export const getByUsername = (username: string) => {
  return http.get<User>(`/user/${username}`)
}
export const getOptions = (usernames: string[]) => {
  return http.post<User[]>('/user/options', usernames)
}
export const resetPassword = (username: string) => {
  return http.put(`/user/reset/${username}`)
}
