import type { Field, Options } from '@/components/Render/type'
import type { FieldRule } from 'vant'

/**
 * 表单配置
 */
export interface FormConf {
  labelPosition: 'left' | 'right' | 'top'
  labelWidth: number
  gutter: number
  disabled: boolean
  fields: FormField[]
  rules: Rule[]
  dataSource: DataSource[]
}

/**
 * 表单字段
 */
export interface FormField extends Field {
  // id
  id: string
  // 类型
  type: 'formItem' | 'container'
  // 默认值
  value?: any
  // 标题
  label: string
  // 只读
  readonly?: boolean
  // 必填
  required?: boolean
  // 隐藏
  hidden: boolean
  // 正则校验
  rules?: FieldRule[]
  // 子字段
  children?: FormField[]
}

/**
 * 数据源
 */
export interface DataSource {
  id: string
  name: string
  url: string
  method: 'get' | 'post' | 'put' | 'delete'
  init: boolean
  params: Recordable
  headers: Recordable
  data: Recordable
  dataKey: string
  dataValue: string
  dataPath: string
}

export interface Rule {
  // 条件
  condition: FilterGroup
  // 执行
  actions: Action[]
}

// 触发事件
export type TriggerEvent =
  | 'show' // 显示
  | 'hide' // 隐藏
  | 'required' // 必填
  | 'notRequired' // 非必填
  | 'enabled' // 启用
  | 'readonly' // 只读
  | 'set' // 设置值
  | 'source' // 触发数据源

export interface Action {
  field: string
  trigger: TriggerEvent
  value: any
}

export type Callback = (options: Options[]) => void

export type FilterOperator =
  | 'eq' // 等于
  | 'ne' // 不等于
  | 'gt' // 大于
  | 'ge' // 大于或等于
  | 'lt' // 小于
  | 'le' // 小于或等于
  | 'bt' // 介于
  | 'nb' // 不介于
  | 'ul' // 为空
  | 'nu' // 不为空
  | 'lk' // 包含
  | 'nl' // 不包含
  | 'in' // 在...之中
  | 'ni' // 不在...之中

/**
 * 条件
 */
export interface FilterCondition {
  // 筛选字段
  field?: string
  // 条件运算符
  operator: FilterOperator
  // 筛选值
  value?: any
}

/**
 * 筛选组
 */
export interface FilterGroup {
  operator: 'or' | 'and'
  conditions: FilterCondition[]
  groups?: FilterGroup[]
}
