import { defineStore } from 'pinia'
import type { LoginForm, loginForm2, UserInfo } from '@/api/modules/oauth/auth'
import { getInfo, login, logout, saltLogin, refreshToken } from '@/api/modules/oauth/auth'
import router from '@/router'

interface AuthState {
  accessToken?: string
  refreshToken?: string
  userInfo?: UserInfo
}

export const useAuthStore = defineStore({
  id: 'app-user',
  state: (): AuthState => ({
    accessToken: undefined,
    refreshToken: undefined,
    userInfo: undefined
  }),
  getters: {
    tokenGet: (state) => state.accessToken,
    refreshTokenGet: (state) => state.refreshToken,
    usernameGet: (state) => state.userInfo?.username,
    nameGet: (state) => state.userInfo?.name,
    avatarGet: (state) => state.userInfo?.avatar,
    phoneGet: (state) => state.userInfo?.phone
  },
  actions: {
    async login(loginForm: LoginForm) {
      const res = await login(loginForm)
      if (res.success) {
        const { accessToken, refreshToken } = res.data
        this.accessToken = accessToken
        this.refreshToken = refreshToken
        return res.data
      }
    },
    async saltLogin(loginForm2: LoginForm2) {
      const res = await saltLogin(loginForm2)
      if (res.success) {
        const { accessToken, refreshToken } = res.data
        this.accessToken = accessToken
        this.refreshToken = refreshToken
        return res.data
      }
    },
    async logout() {
      try {
        await logout()
      } finally {
        this.$reset()
        router.push('/login')
        // location.reload()
      }
    },
    async refresh() {
      const res = await refreshToken()
      if (res.success) {
        const { accessToken, refreshToken } = res.data
        this.accessToken = accessToken
        this.refreshToken = refreshToken
      }
    },
    async getInfo() {
      const { success, data } = await getInfo()
      if (success) {
        this.userInfo = data
        return data
      }
    }
  },
  persist: {
    key: 'Authentication',
    paths: ['accessToken', 'refreshToken']
  }
})
