import { defineStore } from 'pinia'
import type { RouteLocationNormalized } from 'vue-router'

interface CachedViewState {
  cachedViews: string[]
}

export const useCachedViewStore = defineStore({
  id: 'app-cached-view',
  state: (): CachedViewState => ({
    cachedViews: []
  }),
  getters: {
    cachedViewsGet: (state) => state.cachedViews
  },
  actions: {
    // 添加缓存
    addCached(route: RouteLocationNormalized) {
      route.meta.keepAlive && route.name && this.addCachedView(route.name as string)
    },
    // 添加缓存
    addCachedView(view: string) {
      if (this.cachedViews.includes(view)) return
      this.cachedViews.push(view)
    },
    // 删除缓存
    delCachedView(view: string) {
      const index = this.cachedViews.indexOf(view)
      if (index !== -1) {
        this.cachedViews.splice(index, 1)
      }
    },
    // 删除所有缓存
    delAllCachedViews() {
      this.cachedViews = []
    }
  },
  persist: true
})
