/**
 * @description 耗时
 * @param timeStamp 毫秒
 * @returns {string}
 */
export function durationTime(timeStamp: number): string {
  const SECONDS = 1000
  const MINUTES = SECONDS * 60
  const HOURS = MINUTES * 60
  const DAYS = HOURS * 24
  const days = Math.floor(timeStamp / DAYS)
  const hours = Math.floor((timeStamp % DAYS) / HOURS)
  const minutes = Math.floor((timeStamp % HOURS) / MINUTES)
  const seconds = Math.floor((timeStamp % MINUTES) / SECONDS)
  if (days > 0) {
    return `${days}天${hours > 0 ? hours + '小时' : ''}`
  }
  if (hours > 0) {
    return `${hours}小时${minutes > 0 ? minutes + '分钟' : ''}`
  }
  return `${minutes > 0 ? minutes + '分钟' : ''}${seconds}秒`
}

/**
 * @description 格式化时间
 * @param time
 * @returns {string}
 */
export function relativeTime(time: string | number | Date): string {
  const date = new Date(time)
  const now = Date.now()
  const diff = (now - date.getTime()) / 1000
  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) {
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 30) {
    return Math.ceil(diff / (3600 * 24)) + '天前'
  } else if (diff < 3600 * 24 * 30 * 12) {
    return Math.ceil(diff / (3600 * 24 * 30)) + '月前'
  } else {
    return Math.ceil(diff / (3600 * 24 * 30 * 12)) + '年前'
  }
}
